@@ -134,6 +134,8 @@ def smiles2mol(
         constructed.
     :param progressbar: Whether to show a progressbar or not.
     :returns: A pandas DataFrame with new RDKIT Mol objects column.
+    :raises ValueError: if ``progressbar`` is not one of
+        ``"notebook"``, ``"terminal"``, or ``None``.
     """
     valid_progress = ["notebook", "terminal", None]
     if progressbar not in valid_progress:
@@ -247,6 +249,8 @@ def morgan_fingerprint(
     :param nbits: The length of the fingerprints. Defaults to 2048.
     :param kind: Whether to return counts or bits. Defaults to counts.
     :returns: A new pandas DataFrame of Morgan fingerprints.
+    :raises ValueError: if ``kind`` is not one of
+        ``"counts"`` or ``"bits"``.
     """
     acceptable_kinds = ["counts", "bits"]
     if kind not in acceptable_kinds:
